﻿namespace Kreta.Framework.Entities
{
    /// <summary>
    /// Entitás eseményeket kezelő osztályok felülete. Lásd még <see cref="EntityHandler"/>.
    /// </summary>
    public interface IEntityHandler
    {
        /// <summary>
        /// Az entitás insert művelete előtt fut le.
        /// </summary>
        /// <param name="entity">Az entitás</param>
        void BeforeInsert(Entity entity);

        /// <summary>
        /// Az entitás insert művelete után fut le.
        /// </summary>
        /// <param name="entity">Az entitás</param>
        void AfterInsert(Entity entity);

        /// <summary>
        /// Az entitás update művelete előtt fut le.
        /// </summary>
        /// <param name="entity">Az entitás</param>
        void BeforeUpdate(Entity entity);

        /// <summary>
        /// Az entitás update művelete után fut le.
        /// </summary>
        /// <param name="entity">Az entitás</param>
        void AfterUpdate(Entity entity);

        /// <summary>
        /// Az entitás delete művelete előtt fut le.
        /// </summary>
        /// <param name="entity">Az entitás</param>
        void BeforeDelete(Entity entity);

        /// <summary>
        /// Az entitás delete művelete után fut le.
        /// </summary>
        /// <param name="entity">Az entitás</param>
        void AfterDelete(Entity entity);

        /// <summary>
        /// Létre van-e hozva az entitáshoz EntityHandler
        /// </summary>
        bool IsCreated { get; set; }
    }
}
